Contributors
============

Lead:

- `@ericmjl <https://github.com/ericmjl/pyjanitor/pulls?q=is%3Apr+author%3Aericmjl>`_

With thanks to the following contributors:

- `@JoshuaC3 <https://github.com/ericmjl/pyjanitor/pulls?q=is%3Apr+author%3AJoshuaC3>`_
- `@szuckerman <https://github.com/ericmjl/pyjanitor/pulls?q=is%3Apr+author%3Aszuckerman>`_
- `@HectorM14 <https://github.com/HectorM14>`_
- `@cduvallet <https://github.com/cduvallet>`_
- `@zbarry <https://github.com/zbarry>`_
- `@shantanuo <https://github.com/shantanuo>`_

